@@ -1,4 +1,4 @@
-windows::include_bindings!();
+windows::runtime::include_bindings!();
 
 pub mod browser_version;
 
